=======
Credits
=======

Thonny is thankful to:

Its home
--------
Thonny grew up in University of Tartu (https://www.ut.ee), Institute of Computer Science (https://www.cs.ut.ee).

Supporters
----------
* Development of several features in Thonny 3.0 was proposed and supported by Raspberry Pi Foundation (https://www.raspberrypi.org).
* Since September 2018, development of Thonny is partially supported by Cybernetica AS (https://cyber.ee).

Python
------
It's a really nice language for teaching programming. It also has some nice technical properties, that made Thonny's program animation features pleasure to implement.

Libraries, resources and tools
------------------------------
* jedi (http://jedi.readthedocs.io) is used for code completion, go to definition, etc.
* pylint (https://www.pylint.org/) is used as one of the engines behind warnings presented by the Assistant.
* mypy (http://mypy-lang.org/) is used, just like pylint, as a warning engine in the Assistant.
* certifi (https://pypi.python.org/pypi/certifi) provides SSL certs for bundled Python in Linux and Mac.
* distro (https://pypi.python.org/pypi/distro) is optionally used for detecting Linux version in About dialog.
* Most icons are taken from Eclipse project (https://www.eclipse.org/, https://github.com/eclipse/eclipse.platform.debug/tree/master/org.eclipse.debug.ui/icons/full/, https://github.com/eclipse/eclipse.platform.ui/tree/master/bundles/org.eclipse.ui/icons/full/, https://github.com/eclipse/eclipse.jdt.ui/tree/master/org.eclipse.jdt.ui/icons/full/), on Linux, some are overriden by Tango icons (http://tango.freedesktop.org/)
* POEditor (https://poeditor.com/) is used for managing translations of UI strings.

Source contributors, advisors, translators and frequent bug-reporters
---------------------------------------------------------------------
* Aivar Annamaa
* Alar Leemet
* Aleks ANDRÉ
* Alex Hall
* Anatoly Techtonik
* André Roberge
* Austin Bart
* badukaire
* cefn
* Chad Purdy
* cspaier
* cubimon
* Filip Schouwenaars
* Fizban
* fstengel
* Georges Khaznadar
* Илья Кругликов
* Jens Diemer
* Juan Falgueras
* Kauri Raba
* Matt Iversen
* Miro Hrončok 
* Phil Duby
* Rene Lehtma
* segalion
* Simon Long
* Sven Duzont
* Taavi Ilp
* Toomas Mölder
* Xin Rong
* 涂紳騰 (Shen-Teng Tu)

Please let us know if we have forgotten to add your name to this list! Also, let us know if you want to remove your name.